@@ -3,5 +3,5 @@
 set -e # Abort on error
 
 mkdir build && cd build
-cmake -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=$PREFIX ..
-cmake --build . --target install
\ No newline at end of file
+cmake -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=$PREFIX -GNinja ..
+cmake --build . --target install
